#!/bin/bash
#
# Monitor whether the remote test system is down and 
# reboot it if true, running on an HMC server
#
# Copyright (C) 2006 IBM Corp.
# 
# This file is part of systemtap, and is free software.  You can
# redistribute it and/or modify it under the terms of the GNU General
# Public License (GPL); either version 2, or (at your option) any
# later version.
#
# Created by Gui Jian <guijian@cn.ibm.com>
#
TESTSYSTEM_NAME="some_name"
TESTSYSTEM_ID="some_id"
TESTSYSTEM_ADDR="some_ip"
TIMEOUT=20

MAXPINGS=4
MAXREBOOTS=10

ping_retries=0
reboot_retries=0

while [ 1 ]
do
  sleep 10
  ping -w $TIMEOUT $TESTSYSTEM_ADDR -c 3
  if [ $? -eq 0 ]
  then
    ping_retries=0
    echo "ping_retries=$ping_retries, reboot_retries=$reboot_retries"
  else
    ping_retries=$(expr $ping_retries + 1)
    echo "ping_retries=$ping_retries, reboot_retries=$reboot_retries"
    if [ $ping_retries -ge $MAXPINGS ]
    then
      if [ $reboot_retries -lt $MAXREBOOTS ]
      then
        # restart the remote lpar
        chsysstate -r lpar -m $TESTSYSTEM_NAME --id $TESTSYSTEM_ID -o shutdown --immed --restart
        reboot_retries=$(expr $reboot_retries + 1)
        ping_retries=0
      else
        break
      fi
    fi
  fi
done

echo "Max reboot retries reached. Stopped."
exit 0
